==> migrate-1.6.9.src.tar.gz: migrate-1.6.9/src/sighandler.h <==
#ifndef SIGNAL_HANDLER
#define SIGNAL_HANDLER
/* -----------------------------------------------------
   sighandler.h                                           
   handels to following signals:                          
   SIGIOT         Input/Output problems                   
   SIGFPE         Floating point exceptions               
   SIGBUS         Bus error                               
   SIGSEGV        Segmentation fault                      
   SIGXCPU        CPU time limit exceeded                 
   SIGXFSZ        File size limit exceeded                
   if most of those exception are encountered the system  
   tries to exit gracefully, but with some it dies        
   anyway, but tries to say it why in a way which is     
   for humans better understandable                       
   -----------------------------------------------------  
   part of the lamarc package                             
 
   P. Beerli                                              
   ----------------------------------------------------- */
#ifdef NEXTAPP
#include <libc.h>
#endif
#define ON 1
#define OFF 0
extern void signalhandling (long switcher);
extern void signalhandler (int sig);
extern void warning (char string[], ...);
extern void usererror (char string[], ...);
#define error(x) sig_error(x, __FILE__,__LINE__)
extern void sig_error (char string[], char filename[], long line);
#include <stdio.h>

extern char *myfgets (char *buffer, long bufsize, FILE * infile);

#ifdef NEXTAPP
extern void malloc_error_found (int value);
#endif
#ifdef LAMARC_MALLOC
extern void *LAMARC_malloc (const unsigned long size, const char file[],
                                const long line);
extern void *LAMARC_calloc (const unsigned long repeats,
                                const unsigned long size, const char file[],
                                const long line);
extern void *LAMARC_realloc (void *ptr, const unsigned long size,
                                 const char file[], const long line);
#define malloc(a) LAMARC_malloc((unsigned long) a,__FILE__,__LINE__)
#define calloc(b,a) LAMARC_calloc((unsigned long) b, a,__FILE__,__LINE__)
#define realloc(c,a) LAMARC_realloc(c, (unsigned long) a,__FILE__,__LINE__)
#endif

#ifdef DEBUG_MPI
#define MPI_Send(a,b,c,d,e,f) printf("%i>before send (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Send(a,b,c,d,e,f);printf("%i>after send (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#define MPI_Recv(a,b,c,d,e,f,g) printf("%i>before receive (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Recv(a,b,c,d,e,f,g);printf("%i>after receive (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#define MPI_Bcast(a,b,c,d,e) printf("%i>before broadcast (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Bcast(a,b,c,d,e);printf("%i>after broadcast (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#define MPI_Barrier(a) printf("%i>before barrier (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Barrier(a);printf("%i>after barrier (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#endif
#endif

==> migrate-1.7.1.src.tar.gz: migrate-1.7.1/src/sighandler.h <==
#ifndef SIGNAL_HANDLER
#define SIGNAL_HANDLER
/* -----------------------------------------------------
   sighandler.h                                           
   handels to following signals:                          
   SIGIOT         Input/Output problems                   
   SIGFPE         Floating point exceptions               
   SIGBUS         Bus error                               
   SIGSEGV        Segmentation fault                      
   SIGXCPU        CPU time limit exceeded                 
   SIGXFSZ        File size limit exceeded                
   if most of those exception are encountered the system  
   tries to exit gracefully, but with some it dies        
   anyway, but tries to say it why in a way which is     
   for humans better understandable                       
   -----------------------------------------------------  
   part of the lamarc package                             
 
   P. Beerli                                              
   ----------------------------------------------------- */
#include "definitions.h"
#ifdef NEXTAPP
#include <libc.h>
#endif
#define ON 1
#define OFF 0
extern void signalhandling (long switcher);
extern void signalhandler (int sig);
extern void warning (char string[], ...);
extern void usererror (char string[], ...);
#define error(x) sig_error(x, __FILE__,__LINE__)
extern void sig_error (char string[], char filename[], long line);
#include <stdio.h>

extern char *myfgets (char *buffer, long bufsize, FILE * infile);

#ifdef NEXTAPP
extern void malloc_error_found (int value);
#endif
#ifdef LAMARC_MALLOC
extern void *LAMARC_malloc (const unsigned long size, const char file[],
                                const long line);
extern void *LAMARC_calloc (const unsigned long repeats,
                                const unsigned long size, const char file[],
                                const long line);
extern void *LAMARC_realloc (void *ptr, const unsigned long size,
                                 const char file[], const long line);
#define malloc(a) LAMARC_malloc((unsigned long) a,__FILE__,__LINE__)
#define calloc(b,a) LAMARC_calloc((unsigned long) b, a,__FILE__,__LINE__)
#define realloc(c,a) LAMARC_realloc(c, (unsigned long) a,__FILE__,__LINE__)
#endif
#ifdef MPI
#ifdef DEBUG_MPI
#define MYMPISEND(a,b,c,d,e,f) printf("%i>before send of %li bytes (%s,%i)\n",myID, b* sizeof(c),__FILE__,__LINE__);fflush(stdout);MPI_Send(a,b,c,d,e,f);printf("%i>after send (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#define MYMPIRECV(a,b,c,d,e,f,g) printf("%i>before receive of %li bytes (%s,%i)\n",myID, b* sizeof(c), __FILE__,__LINE__);fflush(stdout);MPI_Recv(a,b,c,d,e,f,g);printf("%i>after receive (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#define MYMPIBCAST(a,b,c,d,e) printf("%i>before broadcast of %li bytes (%s,%i)\n",myID, ((long) b) * ((long) sizeof(c)), __FILE__,__LINE__);fflush(stdout);MPI_Bcast(a,b,c,d,e);printf("%i>after broadcast (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#define MYMPIBARRIER(a) printf("%i>before barrier (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Barrier(a);printf("%i>after barrier (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
#else
#define MYMPISEND(a,b,c,d,e,f) MPI_Send(a,b,c,d,e,f)
#define MYMPIRECV(a,b,c,d,e,f,g) MPI_Recv(a,b,c,d,e,f,g)
#define MYMPIBCAST(a,b,c,d,e) MPI_Bcast(a,b,c,d,e)
#define MYMPIBARRIER(a) MPI_Barrier(a)
#endif
#endif
#endif
